Method: CukeModeler::Table#inspect

Defined in:
lib/cuke_modeler/models/table.rb

#inspect(verbose: false) ⇒ String

See ‘Object#inspect`. Returns some basic information about the object, including its class, object ID, and its most meaningful attribute. For a Table model, this will be the rows of the table. If verbose is true, provides default Ruby inspection behavior instead.

Examples:

table.inspect
table.inspect(verbose: true)

Parameters:

  • verbose (Boolean) (defaults to: false)

    Whether or not to return the full details of the object. Defaults to false.

Returns:

  • (String)

    A string representation of this model



66
67
68
69
70
71
72
# File 'lib/cuke_modeler/models/table.rb', line 66

def inspect(verbose: false)
  return super if verbose

  row_output = @rows&.collect { |row| row.cells.collect(&:value) }

  "#{super.chop} @rows: #{row_output.inspect}>"
end