Method: CukeModeler::Table#children
- Defined in:
- lib/cuke_modeler/models/table.rb
#children ⇒ Array<Row>
Returns the model objects that are children of this model. For a Table model, these would be any associated Row models.
38 39 40 |
# File 'lib/cuke_modeler/models/table.rb', line 38 def children rows end |