Method: CukeModeler::Table#to_s
- Defined in:
- lib/cuke_modeler/models/table.rb
#to_s ⇒ String
Returns a string representation of this model. For a Table model, this will be Gherkin text that is equivalent to the table being modeled.
49 50 51 |
# File 'lib/cuke_modeler/models/table.rb', line 49 def to_s rows.empty? ? '' : rows.collect { |row| row_output_string(row) }.join("\n") end |